Object.defineProperty(exports, "__esModule", { value: true });
var Sequence_1 = require("./Sequence");
var DropWhileIterator = (function () {
    function DropWhileIterator(iterator, predicate) {
        this.iterator = iterator;
        this.predicate = predicate;
        this.done = false;
        this.dropping = true;
    }
    DropWhileIterator.prototype.hasNext = function () {
        this.processNext();
        return !this.done;
    };
    DropWhileIterator.prototype.next = function () {
        this.processNext();
        var result = this.nextItem;
        this.nextItem = undefined;
        return result;
    };
    DropWhileIterator.prototype.processNext = function () {
        if (this.done || this.nextItem !== undefined) {
            return;
        }
        while (this.iterator.hasNext()) {
            var item = this.iterator.next();
            if (!this.dropping) {
                this.nextItem = item;
                return;
            }
            var result = this.predicate(item);
            if (!result) {
                this.dropping = false;
                this.nextItem = item;
                return;
            }
        }
        this.done = true;
    };
    return DropWhileIterator;
}());
/**
 * Drops all elements of the sequence as long as the given `predicate` evaluates to true.
 *
 * @param {(item: T) => boolean} predicate
 * @returns {Sequence<T>}
 */
function dropWhile(predicate) {
    return new Sequence_1.default(new DropWhileIterator(this.iterator, predicate));
}
exports.default = dropWhile;
//# sourceMappingURL=dropWhile.js.map