Object.defineProperty(exports, "__esModule", { value: true });
/**
 * Reduces the whole sequence to a single value by invoking `operation` with each element
 * from left to right. For every invocation of the operation `acc` is the result of the last
 * invocation. For the first invocation of the operation `acc` is the first element of the
 * sequence. In addition the `index` of the current element is also passed to the operation.
 *
 * @param {(index: number, acc: S, element: T) => S} operation
 * @returns {S}
 */
function reduceIndexed(operation) {
    if (!this.iterator.hasNext()) {
        throw new Error("Cannot reduce empty sequence");
    }
    var index = 1;
    var result = this.iterator.next();
    while (this.iterator.hasNext()) {
        var item = this.iterator.next();
        result = operation(index, result, item);
        index++;
    }
    return result;
}
exports.default = reduceIndexed;
//# sourceMappingURL=reduceIndexed.js.map