Object.defineProperty(exports, "__esModule", { value: true });
var Sequence_1 = require("./Sequence");
var SequenceIterator_1 = require("./SequenceIterator");
var createComparatorFactory_1 = require("./createComparatorFactory");
/**
 * Returns a new sequence with all elements sorted by the comparator specified by the given `composeComparator` function
 * or in natural order if no arguments are given.
 *
 * @returns {Sequence<T>}
 */
function sorted(composeComparator) {
    var result = [];
    while (this.iterator.hasNext()) {
        var item = this.iterator.next();
        result.push(item);
    }
    if (composeComparator == null) {
        result.sort();
    }
    else {
        var factory = createComparatorFactory_1.default();
        var comparator = composeComparator(factory);
        result.sort(comparator);
    }
    return new Sequence_1.default(new SequenceIterator_1.IterableIterator(result));
}
exports.default = sorted;
//# sourceMappingURL=sorted.js.map