Object.defineProperty(exports, "__esModule", { value: true });
var Sequence_1 = require("./Sequence");
var TakeWhileIterator = (function () {
    function TakeWhileIterator(iterator, predicate) {
        this.iterator = iterator;
        this.predicate = predicate;
        this.done = false;
    }
    TakeWhileIterator.prototype.hasNext = function () {
        this.processNext();
        return !this.done;
    };
    TakeWhileIterator.prototype.next = function () {
        this.processNext();
        var result = this.nextItem;
        this.nextItem = undefined;
        return result;
    };
    TakeWhileIterator.prototype.processNext = function () {
        if (this.done || this.nextItem !== undefined) {
            return;
        }
        if (this.iterator.hasNext()) {
            var item = this.iterator.next();
            var result = this.predicate(item);
            if (result) {
                this.nextItem = item;
                return;
            }
        }
        this.done = true;
    };
    return TakeWhileIterator;
}());
/**
 * Takes all elements of the sequence as long as the given `predicate` evaluates to true.
 *
 * @param {(item: T) => boolean} predicate
 * @returns {Sequence<T>}
 */
function takeWhile(predicate) {
    return new Sequence_1.default(new TakeWhileIterator(this.iterator, predicate));
}
exports.default = takeWhile;
//# sourceMappingURL=takeWhile.js.map